@@ -79,6 +79,7 @@ def _get_inventory_path(parsed_args):
 
 def _validate_args(parsed_args, playbooks):
     """Validate Kayobe Ansible arguments."""
+    vault.validate_args(parsed_args)
     result = utils.is_readable_dir(parsed_args.config_path)
     if not result["result"]:
         LOG.error("Kayobe configuration path %s is invalid: %s",
@@ -124,7 +125,7 @@ def build_args(parsed_args, playbooks,
         cmd += ["-" + "v" * verbose_level]
     if parsed_args.list_tasks:
         cmd += ["--list-tasks"]
-    cmd += vault.build_args(parsed_args)
+    cmd += vault.build_args(parsed_args, "--vault-password-file")
     inventory = _get_inventory_path(parsed_args)
     cmd += ["--inventory", inventory]
     vars_files = _get_vars_files(parsed_args.config_path)
@@ -152,13 +153,6 @@ def build_args(parsed_args, playbooks,
     return cmd
 
 
-def _read_vault_password_file(vault_password_file):
-    """Return the password from a vault password file."""
-    vault_password = utils.read_file(vault_password_file)
-    vault_password = vault_password.strip()
-    return vault_password
-
-
 def run_playbooks(parsed_args, playbooks,
                   extra_vars=None, limit=None, tags=None, quiet=False,
                   verbose_level=None, check=None):
@@ -168,13 +162,7 @@ def run_playbooks(parsed_args, playbooks,
                      extra_vars=extra_vars, limit=limit, tags=tags,
                      verbose_level=verbose_level, check=check)
     env = os.environ.copy()
-    # If the Vault password has been specified via --vault-password-file,
-    # ensure the environment variable is set, so that it can be referenced by
-    # playbooks to generate the kolla-ansible passwords.yml file.
-    if vault.VAULT_PASSWORD_ENV not in env and parsed_args.vault_password_file:
-        vault_password = _read_vault_password_file(
-            parsed_args.vault_password_file)
-        env[vault.VAULT_PASSWORD_ENV] = vault_password
+    vault.update_environment(parsed_args, env)
     # If the configuration path has been specified via --config-path, ensure
     # the environment variable is set, so that it can be referenced by
     # playbooks.
@@ -262,3 +250,19 @@ def install_galaxy_roles(parsed_args, force=False):
 
     # Install roles from kayobe-config.
     utils.galaxy_install(kc_reqs_path, kc_roles_path, force=force)
+
+
+def prune_galaxy_roles(parsed_args):
+    """Prune galaxy roles that are no longer necessary.
+
+    :param parsed_args: Parsed command line arguments.
+    """
+    LOG.info("Removing unnecessary galaxy roles from kayobe")
+    roles_to_remove = [
+        'stackhpc.os-flavors',
+        'stackhpc.os-projects',
+        'stackhpc.parted-1-1',
+        'yatesr.timezone',
+    ]
+    LOG.debug("Removing roles: %s", ",".join(roles_to_remove))
+    utils.galaxy_remove(roles_to_remove, "ansible/roles")
